# -*- perl -*-

#
# Author: Slaven Rezic
#
# Copyright (C) 2012 Slaven Rezic. All rights reserved.
# This package is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
#
# Mail: slaven@rezic.de
# WWW:  http://www.rezic.de/eserte/
#

package Acme::Study::SREZIC;

use XML::LibXML;
use GD;

1;

__END__

=head1 NAME

Acme::SREZIC::Study::Something - use the cpantesters cloud for testing bugs/features/...

=head1 SYNOPSIS

None.

=head1 DESCRIPTION

The both statements

   use XML::LibXML; use GD;

in exactly this order may segfault or loop endlessly on some systems.

=head1 AUTHOR

Slaven Rezic.

=head1 SEE ALSO

L<Acme::Study::Perl>.

=cut
